.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xmasked_view
============

Defined in ``xtensor/xmasked_view.hpp``

.. doxygenclass:: xt::xmasked_view
   :members:
